@@ -37,11 +37,13 @@ class BaseProbaDist(ABC):
     __slots__ = (
         '_space',
         '_sample_func',
+        '_mean_func',
         '_mode_func',
         '_log_proba_func',
         '_entropy_func',
         '_cross_entropy_func',
         '_kl_divergence_func',
+        '_affine_transform_func',
         '_default_priors_func',
     )
 
@@ -85,6 +87,27 @@ class BaseProbaDist(ABC):
         """
         return self._sample_func
 
+    @property
+    def mean(self):
+        r"""
+
+        JIT-compiled functions that generates differentiable means of the distribution.
+
+        Parameters
+        ----------
+        dist_params : pytree with ndarray leaves
+
+            A batch of distribution parameters.
+
+        Returns
+        -------
+        X : ndarray
+
+            A batch of differentiable variates.
+
+        """
+        return self._mean_func
+
     @property
     def mode(self):
         r"""
@@ -205,6 +228,49 @@ class BaseProbaDist(ABC):
         """
         return self._kl_divergence_func
 
+    @property
+    def affine_transform(self):
+        r"""
+
+        Transform the distribution :math:`\mathcal{D}\to\mathcal{D}'` in such a way that its
+        associated variables :math:`X\sim\mathcal{D}` and :math:`X'\sim\mathcal{D}'` are related
+        via an affine transformation:
+
+        .. math::
+
+            X' = X\times\text{scale} + \text{shift}
+
+        Parameters
+        ----------
+        dist_params : pytree with ndarray leaves
+
+            The distribution parameters of the original distribution :math:`\mathcal{D}`.
+
+        scale : float or ndarray
+
+            The multiplicative factor of the affine transformation.
+
+        shift : float or ndarray
+
+            The additive shift of the affine transformation.
+
+        value_transform : ValueTransform, optional
+
+            The transform to apply to the values before the affine transform, i.e.
+
+            .. math::
+
+                X' = f\bigl(f^{-1}(X)\times\text{scale} + \text{shift}\bigr)
+
+        Returns
+        -------
+        dist_params : pytree with ndarray leaves
+
+            The distribution parameters of the transformed distribution :math:`\mathcal{D}'`.
+
+        """
+        return self._affine_transform_func
+
     @property
     def dist_params_structure(self):
         r""" The tree structure of the distribution parameters. """
