@@ -28,10 +28,9 @@ import numpy as onp
 import haiku as hk
 from scipy.linalg import pascal
 
-from .._base.errors import NumpyArrayCheckError
-
 
 __all__ = (
+    'StepwiseLinearFunction',
     'argmax',
     'argmin',
     'batch_to_single',
@@ -44,6 +43,7 @@ __all__ = (
     'double_relu',
     'get_grads_diagnostics',
     'get_magnitude_quantiles',
+    'get_transition_batch',
     'idx',
     'isscalar',
     'merge_dicts',
@@ -150,63 +150,51 @@ def batch_to_single(pytree, index=0):
     return jax.tree_map(lambda arr: arr[index], pytree)
 
 
-def check_array(arr, ndim=None, ndim_min=None, ndim_max=None, dtype=None, shape=None, axis_size=None, axis=None):  # noqa: E501
-    """
+def check_array(
+        arr, ndim=None, ndim_min=None, ndim_max=None,
+        dtype=None, shape=None, axis_size=None, axis=None):
+    r"""
 
     This helper function is mostly for internal use. It is used to check a few
     common properties of a numpy array.
 
     Raises
     ------
-    NumpyArrayCheckError
+    TypeError
 
-        If one of the checks fails, it raises a :class:`NumpyArrayCheckError`.
+        If one of the checks fails.
 
     """
-
     if not isinstance(arr, jnp.ndarray):
-        raise NumpyArrayCheckError(
-            "expected input to be a numpy array, got type: {}"
-            .format(type(arr)))
+        raise TypeError("expected input to be a numpy array, got type: {}".format(type(arr)))
 
     check = ndim is not None
     ndims = [ndim] if not isinstance(ndim, (list, tuple, set)) else ndim
     if check and arr.ndim not in ndims:
-        raise NumpyArrayCheckError(
-            "expected input with ndim(s) {}, got ndim: {}"
-            .format(ndim, arr.ndim))
+        raise TypeError(f"expected input with ndim(s) {ndim}, got ndim: {arr.ndim}")
 
     check = ndim_min is not None
     if check and arr.ndim < ndim_min:
-        raise NumpyArrayCheckError(
-            "expected input with ndim at least {}, got ndim: {}"
-            .format(ndim_min, arr.ndim))
+        raise TypeError(f"expected input with ndim at least {ndim_min}, got ndim: {arr.ndim}")
 
     check = ndim_max is not None
     if check and arr.ndim > ndim_max:
-        raise NumpyArrayCheckError(
-            "expected input with ndim at most {}, got ndim: {}"
-            .format(ndim_max, arr.ndim))
+        raise TypeError(f"expected input with ndim at most {ndim_max}, got ndim: {arr.ndim}")
 
     check = dtype is not None
     dtypes = [dtype] if not isinstance(dtype, (list, tuple, set)) else dtype
     if check and arr.dtype not in dtypes:
-        raise NumpyArrayCheckError(
-            "expected input with dtype(s) {}, got dtype: {}"
-            .format(dtype, arr.dtype))
+        raise TypeError(f"expected input with dtype(s) {dtype}, got dtype: {arr.dtype}")
 
     check = shape is not None
     if check and arr.shape != shape:
-        raise NumpyArrayCheckError(
-            "expected input with shape {}, got shape: {}"
-            .format(shape, arr.shape))
+        raise TypeError(f"expected input with shape {shape}, got shape: {arr.shape}")
 
     check = axis_size is not None and axis is not None
-    sizes = [axis_size] if not isinstance(axis_size, (list, tuple, set)) else axis_size  # noqa: E501
+    sizes = [axis_size] if not isinstance(axis_size, (list, tuple, set)) else axis_size
     if check and arr.shape[axis] not in sizes:
-        raise NumpyArrayCheckError(
-            "expected input with size(s) {} along axis {}, got shape: {}"
-            .format(axis_size, axis, arr.shape))
+        raise TypeError(
+            f"expected input with size(s) {axis_size} along axis {axis}, got shape: {arr.shape}")
 
 
 def check_preprocessors(space, *preprocessors, num_samples=20, random_seed=None):
@@ -578,6 +566,64 @@ def get_magnitude_quantiles(pytree, key_prefix=''):
     return dict(zip(quantile_names, quantiles))
 
 
+def get_transition_batch(env, batch_size=1, gamma=0.9, random_seed=None):
+    r"""
+    Generate a single transition from the environment.
+
+    This basically does a single step on the environment and then closes it.
+
+    Parameters
+    ----------
+    env : gym environment
+
+        A gym-style environment.
+
+    batch_size : positive int, optional
+
+        The desired batch size of the sample.
+
+    random_seed : int, optional
+
+        In order to generate the transition, we do some random sampling from the provided spaces.
+        This `random_seed` set the seed for the pseudo-random number generators.
+
+    Returns
+    -------
+    transition_batch : TransitionBatch
+
+        A batch of transitions.
+
+    """
+    # import inline to avoid circular dependencies
+    from ..reward_tracing import TransitionBatch
+    from ._array import safe_sample
+
+    # check types
+    if not (isinstance(batch_size, int) and batch_size > 0):
+        raise TypeError(f"batch_size must be a positive int, got: {batch_size}")
+    if not (isinstance(gamma, (int, float)) and 0 <= gamma <= 1):
+        raise TypeError(f"gamma must be a float in the unit interval [0,1], got: {gamma}")
+
+    rnd = onp.random.RandomState(random_seed)
+
+    def batch_sample(space):
+        max_seed = onp.iinfo('int32').max
+        X = [safe_sample(space, seed=rnd.randint(max_seed)) for _ in range(batch_size)]
+        return jax.tree_multimap(lambda *leaves: onp.stack(leaves, axis=0), *X)
+
+    return TransitionBatch(
+        S=batch_sample(env.observation_space),
+        A=batch_sample(env.action_space),
+        logP=onp.log(onp.clip(rnd.rand(batch_size), 0.01, 0.99)),
+        Rn=onp.clip(rnd.randn(batch_size), -5., 5.),
+        In=rnd.choice((0, gamma), batch_size),
+        S_next=batch_sample(env.observation_space),
+        A_next=batch_sample(env.action_space),
+        logP_next=onp.log(onp.clip(rnd.rand(batch_size), 0.01, 0.99)),
+        W=onp.clip(rnd.rand(batch_size) / rnd.rand(batch_size), 0.01, 100.),
+    )
+
+
 def idx(arr, axis=0):
     r"""
     Given a numpy array, return its corresponding integer index array.
@@ -655,6 +701,78 @@ def merge_dicts(*dicts):
     return merged
 
 
+class StepwiseLinearFunction:
+    r"""
+
+    Stepwise linear function. The function remains flat outside of the regions defined by
+    :code:`steps`.
+
+    Parameters
+    ----------
+    \*steps : sequence of tuples (int, float)
+
+        Each step :code:`(timestep, value)` fixes the output value at :code:`timestep` to the
+        provided :code:`value`.
+
+    Example
+    -------
+    Here's an example of the exploration schedule in a DQN agent:
+
+    .. code::
+
+        pi = coax.EpsilonGreedy(q, epsilon=1.0)
+        epsilon = StepwiseLinearFunction((0, 1.0), (1000000, 0.1), (2000000, 0.01))
+
+        for _ in range(num_episodes):
+            pi.epsilon = epsilon(T)  # T is a global step counter
+            ...
+
+    .. image:: /_static/img/piecewise_linear_function.svg
+        :alt: description
+        :width: 100%
+        :align: left
+
+
+    Notice that the function is flat outside the interpolation range provided by :code:`steps`.
+
+
+    """
+    def __init__(self, *steps):
+        if len(steps) < 2:
+            raise TypeError("need at least two steps")
+        if not all(
+                isinstance(s, tuple) and len(s) == 2                          # check if pair
+                and isinstance(s[0], int) and isinstance(s[1], (float, int))  # check types
+                for s in steps):
+            raise TypeError("all steps must be pairs (size-2 tuples) of (int, type(start_value))")
+        if not all(t1 < t2 for (t1, _), (t2, _) in zip(steps, steps[1:])):  # check if consecutive
+            raise ValueError(
+                "steps [(t1, value), ..., (t2, value)] must be provided in ascending order, i.e. "
+                "0 < t1 < t2 < ... < tn")
+
+        self._start_value = float(steps[0][1])
+        self._final_value = float(steps[-1][1])
+        self._offsets = onp.array([t for t, _ in steps])
+        self._intercepts = onp.array([v for _, v in steps])
+        self._index = onp.arange(len(steps))
+        self._slopes = onp.array([
+            (v_next - v) / (t_next - t) for (t, v), (t_next, v_next) in zip(steps, steps[1:])])
+
+    def __call__(self, timestep):
+        r"""
+
+        Return the value according to the provided schedule.
+
+        """
+        mask = self._offsets <= timestep
+        if not onp.any(mask):
+            return self._start_value
+        if onp.all(mask):
+            return self._final_value
+        i = onp.max(self._index[mask])
+        return self._intercepts[i] + self._slopes[i] * (timestep - self._offsets[i])
+
+
 def _safe_sample(space, rnd):
     if isinstance(space, gym.spaces.Discrete):
         return rnd.randint(space.n)
@@ -668,10 +786,8 @@ def _safe_sample(space, rnd):
     if isinstance(space, gym.spaces.Box):
         low = onp.clip(space.low, -1e9, 1e9)
         high = onp.clip(space.high, -1e9, 1e9)
-        midpoints = (low + high) / 2.
-        sizes = onp.clip(high - low, 0, 100)  # clip to reasonable range
-        low = midpoints - sizes / 2.
-        return low + rnd.rand(*space.shape) * sizes
+        x = low + rnd.rand(*space.shape) * (high - low)
+        return onp.sign(x) * onp.log(1. + onp.abs(x))  # log transform to avoid very large numbers
 
     if isinstance(space, gym.spaces.Tuple):
         return tuple(_safe_sample(sp, rnd) for sp in space.spaces)
