@@ -23,6 +23,7 @@ import os
 import re
 import datetime
 import time
+from collections import deque
 from tempfile import TemporaryDirectory
 from zipfile import ZipFile
 from typing import Mapping
@@ -41,6 +42,39 @@ __all__ = (
 )
 
 
+class StreamingSample:
+    def __init__(self, maxlen, random_seed=None):
+        self._deque = deque(maxlen=maxlen)
+        self._count = 0
+        self._rnd = np.random.RandomState(random_seed)
+
+    def reset(self):
+        self._deque = deque(maxlen=self.maxlen)
+        self._count = 0
+
+    def append(self, obj):
+        self._count += 1
+        if len(self) < self.maxlen:
+            self._deque.append(obj)
+        elif self._rnd.rand() < self.maxlen / self._count:
+            i = self._rnd.randint(self.maxlen)
+            self._deque[i] = obj
+
+    @property
+    def values(self):
+        return list(self._deque)  # shallow copy
+
+    @property
+    def maxlen(self):
+        return self._deque.maxlen
+
+    def __len__(self):
+        return len(self._deque)
+
+    def __bool__(self):
+        return bool(self._deque)
+
+
 class TrainMonitor(Wrapper, LoggerMixin, SerializationMixin):
     r"""
     Environment wrapper for monitoring the training process.
@@ -145,7 +179,7 @@ class TrainMonitor(Wrapper, LoggerMixin, SerializationMixin):
         self._n_avg_G = 0.0
         self._ep_starttime = time.time()
         self._ep_metrics = {}
-        self._ep_actions = []
+        self._ep_actions = StreamingSample(maxlen=1000)
         self._period = {'T': {}, 'ep': {}}
 
     def reset(self):
@@ -162,7 +196,7 @@ class TrainMonitor(Wrapper, LoggerMixin, SerializationMixin):
         self.G = 0.0
         self._ep_starttime = time.time()
         self._ep_metrics = {}
-        self._ep_actions = []
+        self._ep_actions.reset()
 
         return self.env.reset()
 
@@ -312,7 +346,7 @@ class TrainMonitor(Wrapper, LoggerMixin, SerializationMixin):
                 else:
                     bins = 'auto'  # see also: np.histogram_bin_edges.__doc__
                 self.tensorboard.add_histogram(
-                    tag='actions', values=self._ep_actions, global_step=self.T, bins=bins)
+                    tag='actions', values=self._ep_actions.values, global_step=self.T, bins=bins)
             if self._ep_metrics and not self.tensorboard_write_all:
                 for k, (x, n) in self._ep_metrics.items():
                     self.tensorboard.add_scalar(str(k), float(x) / n, global_step=self.T)
